==> research-framework-0.1.4.tar.gz: research-framework-0.1.4/research_framework/pipeline/wrappers.py <==

from research_framework.base.plugin.base_plugin import BasePlugin
from research_framework.base.wrappers.filter_wrapper import BaseFilterWrapper
from research_framework.lightweight.lightweight import FlyWeight
from typing import Dict, Any, Optional
import json




class FitPredictFilterWrapper(BaseFilterWrapper):
    def __init__(self, clazz:str, params:Dict[str, Any], filter_object: BasePlugin, fly: FlyWeight):
        self.clazz:str = clazz
        self.params:Dict[str, Any] = params
        self.filter: BasePlugin = filter_object
        self.fly: FlyWeight = fly
        self.hashcode:Optional[str] = None
        self.filter_name:Optional[str] = None
        
    def fit(self, data_hashcode:str, data):
        
        filter_hashcode = self.fly.hashcode_from_config(self.clazz, self.params)
        
        trained_filter_name = f'{self.clazz}{json.dumps(self.params)}[Trained]({data_hashcode})'
        trained_filter_hashcode = self.fly.append_to_hashcode(data_hashcode, filter_hashcode, is_model=True)
        
        filter_trained_item = self.fly.get_item(trained_filter_hashcode)
        
        if filter_trained_item is None:
            #Esto significa que no tenemos el modelo entrenado guardado.
            if callable(data):
                data = data()
            self.filter.fit(data, self.params)
            
            self.fly.set_item(
                trained_filter_name,
                trained_filter_hashcode,
                self.filter)
            
            self.hashcode = trained_filter_hashcode
            self.filter_name = trained_filter_name
            
            
        else:
            self.filter = self.fly.get_object_from_item(filter_trained_item)
            self.hashcode = trained_filter_hashcode
                
            
        
    def predict(self, data_hashcode:str, data_name:str, data):
        if self.hashcode is None:
            raise Exception("Model not trained, call fit() before calling predict()!")
        else:
            data_name = f'{data_name} -> {self.filter_name}',
            data_hashcode = self.fly.append_to_hashcode(data_hashcode, self.hashcode, is_model=False)
            data_item = self.fly.get_item(data_hashcode)
            
            if data_item is None:
                # Esto significa que aun no hemos generado los nuevos datos
                if callable(data):
                    data = data()
                
                data = self.filter.predict(data, self.params)
                
                self.fly.set_item(
                    data_name,
                    data_hashcode,
                    data                    
                )
            else:
                data = lambda : self.fly.get_object_from_item(data_item)
            
            return data_hashcode, data_name, data
                
        
    

class PassThroughFilterWrapper(BaseFilterWrapper):
    def __init__(self, clazz:str, params:Dict[str, Any], filter_object: BasePlugin, fly: FlyWeight, *args, **kwargs):
        self.clazz:str = clazz
        self.params:Dict[str, Any] = params
        self.filter: BasePlugin = filter_object
        self.fly: FlyWeight = fly
        self.hashcode:Optional[str] = None
        self.filter_name:Optional[str] = f'{self.clazz}{json.dumps(self.params)}[-]'
        
    def fit(self, *args, **kwargs): ...
        
    def predict(self, data_hashcode:str, data_name:str, data):
        data_name = f'{data_name} -> {self.filter_name}'
        filter_hashcode = self.fly.hashcode_from_config(self.clazz, self.params)
        data_hashcode = self.fly.append_to_hashcode(data_hashcode, filter_hashcode, is_model=False)
        
        data_item = self.fly.get_item(data_hashcode)
            
        if data_item is None:
            # Esto significa que aun no hemos generado los nuevos datos
            if callable(data):
                data = data()
            
            data = self.filter.predict(data, self.params)
            
            if not self.fly.set_item(
                data_name,
                data_hashcode,
                data                    
            ):
                raise Exception("Couldn't save item")
        else:
            data = lambda : self.fly.get_object_from_item(data_item)
        
        return data_hashcode, data_name, data
    

class InputFiterWrapper(BaseFilterWrapper):
    def __init__(self, clazz:str, params:Dict[str, Any], filter_object: BasePlugin, fly: FlyWeight, *args, **kwargs):
        self.clazz:str = clazz
        self.params:Dict[str, Any] = params
        self.filter: BasePlugin = filter_object
        self.fly: FlyWeight = fly
        
    def fit(self, *args, **kwargs): ...
    
    
    def predict(self, data_name:str, *args, **kwargs):
        data_hashcode = self.fly.hashcode_from_name(data_name)
        
        data_item = self.fly.get_item(data_hashcode)
        
        if data_item is None:
            data = self.filter.predict(None, self.params)
            if not self.fly.set_item(
                data_name,
                data_hashcode,
                data                    
            ):
                raise Exception("Couldn't save item")
            
        else:
            data = lambda: self.filter.predict(None, self.params)
        
        return data_hashcode, data_name, data

==> research-framework-0.1.7.tar.gz: research-framework-0.1.7/research_framework/pipeline/wrappers.py <==

from research_framework.base.plugin.base_plugin import BasePlugin
from research_framework.base.wrappers.filter_wrapper import BaseFilterWrapper
from research_framework.lightweight.lightweight import FlyWeight
from typing import Dict, Any, Optional
import json




class FitPredictFilterWrapper(BaseFilterWrapper):
    def __init__(self, clazz:str, params:Dict[str, Any], filter_object: BasePlugin, fly: FlyWeight):
        self.clazz:str = clazz
        self.params:Dict[str, Any] = params
        self.filter: BasePlugin = filter_object
        self.fly: FlyWeight = fly
        self.hashcode:Optional[str] = None
        self.filter_name:Optional[str] = None
        
    def fit(self, data_hashcode:str, data):
        
        filter_hashcode = self.fly.hashcode_from_config(self.clazz, self.params)
        
        trained_filter_name = f'{self.clazz}{json.dumps(self.params)}[Trained]({data_hashcode})'
        trained_filter_hashcode = self.fly.append_to_hashcode(data_hashcode, filter_hashcode, is_model=True)
        
        filter_trained_item = self.fly.get_item(trained_filter_hashcode)
        
        if filter_trained_item is None:
            #Esto significa que no tenemos el modelo entrenado guardado.
            if callable(data):
                data = data()
            self.filter.fit(data, self.params)
            
            self.fly.set_item(
                trained_filter_name,
                trained_filter_hashcode,
                self.filter
            )
            
            self.hashcode = trained_filter_hashcode
            self.filter_name = trained_filter_name
            
            
        else:
            self.filter = lambda : self.fly.get_object_from_item(filter_trained_item)
            self.hashcode = trained_filter_hashcode
                
            
        
    def predict(self, data_hashcode:str, data_name:str, data):
        if self.hashcode is None:
            raise Exception("Model not trained, call fit() before calling predict()!")
        else:
            data_name = f'{data_name} -> {self.filter_name}',
            data_hashcode = self.fly.append_to_hashcode(data_hashcode, self.hashcode, is_model=False)
            data_item = self.fly.get_item(data_hashcode)
            
            if data_item is None:
                # Esto significa que aun no hemos generado los nuevos datos
                if callable(data):
                    data = data()
                    
                if callable(self.filter) and self.filter.__name__ == "<lambda>":
                    self.filter = self.filter()
                
                data = self.filter.predict(data, self.params)
                
                self.fly.set_item(
                    data_name,
                    data_hashcode,
                    data                    
                )
            else:
                data = lambda : self.fly.get_object_from_item(data_item)
            
            return data_hashcode, data_name, data
                
        
    

class PassThroughFilterWrapper(BaseFilterWrapper):
    def __init__(self, clazz:str, params:Dict[str, Any], filter_object: BasePlugin, fly: FlyWeight, *args, **kwargs):
        self.clazz:str = clazz
        self.params:Dict[str, Any] = params
        self.filter: BasePlugin = filter_object
        self.fly: FlyWeight = fly
        self.hashcode:Optional[str] = None
        self.filter_name:Optional[str] = f'{self.clazz}{json.dumps(self.params)}[-]'
        
    def fit(self, *args, **kwargs): ...
        
    def predict(self, data_hashcode:str, data_name:str, data):
        data_name = f'{data_name} -> {self.filter_name}'
        filter_hashcode = self.fly.hashcode_from_config(self.clazz, self.params)
        data_hashcode = self.fly.append_to_hashcode(data_hashcode, filter_hashcode, is_model=False)
        
        data_item = self.fly.get_item(data_hashcode)
            
        if data_item is None:
            # Esto significa que aun no hemos generado los nuevos datos
            if callable(data):
                data = data()
            
            data = self.filter.predict(data, self.params)
            
            if not self.fly.set_item(
                data_name,
                data_hashcode,
                data                    
            ):
                raise Exception("Couldn't save item")
        else:
            data = lambda : self.fly.get_object_from_item(data_item)
        
        return data_hashcode, data_name, data
    

class InputFiterWrapper(BaseFilterWrapper):
    def __init__(self, clazz:str, params:Dict[str, Any], filter_object: BasePlugin, fly: FlyWeight, *args, **kwargs):
        self.clazz:str = clazz
        self.params:Dict[str, Any] = params
        self.filter: BasePlugin = filter_object
        self.fly: FlyWeight = fly
        
    def fit(self, *args, **kwargs): ...
    
    
    def predict(self, data_name:str, *args, **kwargs):
        data_hashcode = self.fly.hashcode_from_name(data_name)
        
        data_item = self.fly.get_item(data_hashcode)
        
        if data_item is None:
            data = self.filter.predict(None, self.params)
            if not self.fly.set_item(
                data_name,
                data_hashcode,
                data                    
            ):
                raise Exception("Couldn't save item")
            
        else:
            data = lambda: self.filter.predict(None, self.params)
        
        return data_hashcode, data_name, data
